# manifold-learn

manifold-learn is

* a lightweight toolkit making manifold learning much easier





## Quickstart


### Dependencies and Installation

#### Package Dependencies

`pip install -r requirements.txt` can handle all package dependencies.

#### Install PyTorch-Bayes

```bash
$ pip install manifold-learn
```   
